@@ -3,13 +3,14 @@ import subprocess
 from glob import glob
 from pathlib import Path
 from typing import Any, Optional
+from traceback import format_exc
 
 import click
 import docker  # type: ignore
 from docker.errors import ImageNotFound  # type: ignore
 
 from treebeard.buildtime.helper import run_image
-from treebeard.conf import treebeard_env
+from treebeard.conf import run_path, treebeard_env
 from treebeard.util import fatal_exit
 
 
@@ -33,6 +34,9 @@ def run_repo(
     secrets_url: Optional[str],
     local: bool = False,
 ):
+    click.echo(f"🌲 Treebeard buildtime, building repo")
+    click.echo(f"Run path: {run_path}")
+
     client: Any = docker.from_env()  # type: ignore
 
     try:
@@ -61,9 +65,13 @@ def run_repo(
     project_base_image = "docker.io/treebeardtech/project-base-image"
 
     try:
+        click.echo(f"Pulling {image_name}")
         client.images.pull(image_name)
     except ImageNotFound:
         try:
+            click.echo(
+                f"Could not pull {image_name}, instead pulling {project_base_image}"
+            )
             client.images.pull(project_base_image)
         except Exception as ex:
             click.echo(f"Error pulling project base image {ex}, continuing without...")
@@ -86,15 +94,21 @@ def run_repo(
         {abs_notebook_dir}
     """
     subprocess.check_output(["bash", "-c", r2d])
-    subprocess.check_output(["docker", "tag", versioned_image_name, latest_image_name])
 
-    try:
-        run_image(project_id, notebook_id, run_id, image_name)
-    except Exception as ex:
-        if not local:
-            click.echo("Image run failed, pushing failed image...")
-            client.images.push(latest_image_name)
-        raise ex
+    if not local:
+        try:
+            click.echo(f"Image built: Pushing {versioned_image_name}")
+            client.images.push(versioned_image_name)
+        except Exception:
+            click.echo(
+                f"Failed to push image, will try again on success\n{format_exc()}"
+            )
+
+    click.echo(f"Image built successfully, now running.")
+    subprocess.check_output(["docker", "tag", versioned_image_name, latest_image_name])
+    run_image(project_id, notebook_id, run_id, image_name)
+
+    click.echo(f"tagged {versioned_image_name} as {latest_image_name}")
 
 
 if __name__ == "__main__":
