@@ -29,6 +29,7 @@ from treebeard.conf import (
 )
 from treebeard.helper import CliContext
 from treebeard.notebooks.types import Run
+from treebeard.secrets.commands import push_secrets
 from treebeard.secrets.helper import get_secrets_archive
 from treebeard.util import fatal_exit
 
@@ -57,8 +58,16 @@ project_id = treebeard_env.project_id
     help="Don't submit unneeded virtual envs and large files",
     multiple=True,
 )
+@click.option("--confirm/--no-confirm", default=False)
 @click.pass_obj
-def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local: bool):
+def run(
+    cli_context: CliContext,
+    t: str,
+    watch: bool,
+    ignore: List[str],
+    local: bool,
+    confirm: bool,
+):
     """
     Run a notebook and optionally schedule it to run periodically
     """
@@ -69,8 +78,14 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
     if t:
         params["schedule"] = t
 
-    spinner: Any = Halo(text="🌲  Compressing Repo\n", spinner="dots")
-    spinner.start()
+    if not local and not treebeard_config.secret == ():
+        should_push_secrets = confirm or click.confirm(
+            "Push secrets first?", default=True
+        )
+        if should_push_secrets:
+            push_secrets([], confirm=confirm)
+
+    click.echo("🌲  Compressing Repo")
 
     if treebeard_config:
         ignore += (
@@ -79,25 +94,14 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
             + treebeard_config.output_dirs
         )
 
-    # Create a temporary file for the compressed directory
-    # compressed file accessible at f.name
-    # git_files: Set[str] = set(
-    #     subprocess.check_output(
-    #         "git ls-files || exit 0", shell=True, stderr=subprocess.DEVNULL
-    #     )
-    #     .decode()
-    #     .splitlines()
-    # )
-
     with tempfile.NamedTemporaryFile(
         "wb", suffix=".tar.gz", delete=False
     ) as src_archive:
-        click.echo("\n")
         with tarfile.open(fileobj=src_archive, mode="w:gz") as tar:
 
             def zip_filter(info: tarfile.TarInfo):
                 for ignored in ignore:
-                    if info.name in glob.glob(ignored):
+                    if info.name in glob.glob(ignored, recursive=True):
                         return None
 
                 # if len(git_files) > 0 and info.name not in git_files:
@@ -109,6 +113,13 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
                 os.getcwd(), arcname=os.path.basename(os.path.sep), filter=zip_filter
             )
             tar.add(config_path, arcname=os.path.basename(config_path))
+
+    if not (
+        confirm or click.confirm("Confirm source file set is correct?", default=True)
+    ):
+        click.echo("Exiting")
+        sys.exit()
+
     size = os.path.getsize(src_archive.name)
     max_upload_size = "100MB"
     if size > parse_size(max_upload_size):
@@ -122,9 +133,7 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
                 fg="red",
             )
         )
-
     if local:
-        spinner.stop()
         build_tag = str(time.mktime(datetime.today().timetuple()))
         repo_image_name = (
             f"gcr.io/treebeard-259315/projects/{project_id}/{notebook_id}:{build_tag}"
@@ -133,18 +142,20 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
         secrets_archive = get_secrets_archive()
         repo_url = f"file://{src_archive.name}"
         secrets_url = f"file://{secrets_archive.name}"
-        run_repo(
-            str(project_id),
-            str(notebook_id),
-            treebeard_env.run_id,
-            build_tag,
-            repo_url,
-            secrets_url,
-            local=True,
-        )
-        sys.exit(0)
+        try:
+            run_repo(
+                str(project_id),
+                str(notebook_id),
+                treebeard_env.run_id,
+                build_tag,
+                repo_url,
+                secrets_url,
+                local=True,
+            )
+        finally:
+            sys.exit(0)
 
-    spinner.text = "🌲  submitting notebook to runner\n"
+    click.echo(f"🌲  submitting archive to runner ({format_size(size)})...")
     response = requests.post(
         notebooks_endpoint,
         files={"repo": open(src_archive.name, "rb")},
@@ -155,7 +166,6 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
     if response.status_code != 200:
         raise click.ClickException(f"Request failed: {response.text}")
 
-    spinner.stop()
     try:
         json_data = json.loads(response.text)
         click.echo(f"✨  Run has been accepted! {json_data['admin_url']}")
@@ -164,8 +174,6 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
         click.echo(sys.exc_info())
 
     if watch:
-        # spinner = Halo(text='watching build', spinner='dots')
-        # spinner.start()
         build_result = None
         while not build_result:
             time.sleep(5)
@@ -175,7 +183,6 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
             click.echo(f"{get_time()} Build status: {status}")
             if status == "SUCCESS":
                 build_result = status
-                # spinner.stop()
                 click.echo(f"Build result: {build_result}")
             elif status in ["FAILURE", "TIMEOUT", "INTERNAL_ERROR", "CANCELLED"]:
                 fatal_exit(f"Build failed")
@@ -185,12 +192,12 @@ def run(cli_context: CliContext, t: str, watch: bool, ignore: List[str], local:
 def cancel():
     """Cancels the current notebook build and schedule"""
     validate_notebook_directory(treebeard_env, treebeard_config)
-    spinner: Any = Halo(text="cancelling", spinner="dots")
-    click.echo(f"🌲  Cancelling {notebook_id}")
+    notif = f"🌲  Cancelling {notebook_id}"
+    spinner: Any = Halo(text=notif, spinner="dots")
     spinner.start()
     requests.delete(notebooks_endpoint, headers=treebeard_env.dict())
     spinner.stop()
-    click.echo(f"🛑 Done!")
+    click.echo(f"{notif}...🛑 cancellation confirmed!")
 
 
 @click.command()
